# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2/proto/session.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from dialogflow_v2.proto import (
    audio_config_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2,
)
from dialogflow_v2.proto import (
    context_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2,
)
from dialogflow_v2.proto import (
    intent_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2,
)
from dialogflow_v2.proto import (
    session_entity_type_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__entity__type__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.type import latlng_pb2 as google_dot_type_dot_latlng__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2/proto/session.proto",
    package="google.cloud.dialogflow.v2",
    syntax="proto3",
    serialized_options=b"\n\036com.google.cloud.dialogflow.v2B\014SessionProtoP\001ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\370\001\001\242\002\002DF\252\002\032Google.Cloud.Dialogflow.V2\352A\245\001\n!dialogflow.googleapis.com/Session\022+projects/{project}/agent/sessions/{session}\022Sprojects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n.google/cloud/dialogflow_v2/proto/session.proto\x12\x1agoogle.cloud.dialogflow.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x33google/cloud/dialogflow_v2/proto/audio_config.proto\x1a.google/cloud/dialogflow_v2/proto/context.proto\x1a-google/cloud/dialogflow_v2/proto/intent.proto\x1a:google/cloud/dialogflow_v2/proto/session_entity_type.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x17google/rpc/status.proto\x1a\x18google/type/latlng.proto"\xf5\x02\n\x13\x44\x65tectIntentRequest\x12:\n\x07session\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!dialogflow.googleapis.com/Session\x12\x41\n\x0cquery_params\x18\x02 \x01(\x0b\x32+.google.cloud.dialogflow.v2.QueryParameters\x12@\n\x0bquery_input\x18\x03 \x01(\x0b\x32&.google.cloud.dialogflow.v2.QueryInputB\x03\xe0\x41\x02\x12J\n\x13output_audio_config\x18\x04 \x01(\x0b\x32-.google.cloud.dialogflow.v2.OutputAudioConfig\x12<\n\x18output_audio_config_mask\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0binput_audio\x18\x05 \x01(\x0c"\xf8\x01\n\x14\x44\x65tectIntentResponse\x12\x13\n\x0bresponse_id\x18\x01 \x01(\t\x12=\n\x0cquery_result\x18\x02 \x01(\x0b\x32\'.google.cloud.dialogflow.v2.QueryResult\x12*\n\x0ewebhook_status\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12\x14\n\x0coutput_audio\x18\x04 \x01(\x0c\x12J\n\x13output_audio_config\x18\x06 \x01(\x0b\x32-.google.cloud.dialogflow.v2.OutputAudioConfig"\xfc\x02\n\x0fQueryParameters\x12\x11\n\ttime_zone\x18\x01 \x01(\t\x12)\n\x0cgeo_location\x18\x02 \x01(\x0b\x32\x13.google.type.LatLng\x12\x35\n\x08\x63ontexts\x18\x03 \x03(\x0b\x32#.google.cloud.dialogflow.v2.Context\x12\x16\n\x0ereset_contexts\x18\x04 \x01(\x08\x12K\n\x14session_entity_types\x18\x05 \x03(\x0b\x32-.google.cloud.dialogflow.v2.SessionEntityType\x12(\n\x07payload\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x65\n!sentiment_analysis_request_config\x18\n \x01(\x0b\x32:.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig"\xcb\x01\n\nQueryInput\x12\x44\n\x0c\x61udio_config\x18\x01 \x01(\x0b\x32,.google.cloud.dialogflow.v2.InputAudioConfigH\x00\x12\x35\n\x04text\x18\x02 \x01(\x0b\x32%.google.cloud.dialogflow.v2.TextInputH\x00\x12\x37\n\x05\x65vent\x18\x03 \x01(\x0b\x32&.google.cloud.dialogflow.v2.EventInputH\x00\x42\x07\n\x05input"\x90\x05\n\x0bQueryResult\x12\x12\n\nquery_text\x18\x01 \x01(\t\x12\x15\n\rlanguage_code\x18\x0f \x01(\t\x12%\n\x1dspeech_recognition_confidence\x18\x02 \x01(\x02\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x12+\n\nparameters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12#\n\x1b\x61ll_required_params_present\x18\x05 \x01(\x08\x12\x18\n\x10\x66ulfillment_text\x18\x06 \x01(\t\x12H\n\x14\x66ulfillment_messages\x18\x07 \x03(\x0b\x32*.google.cloud.dialogflow.v2.Intent.Message\x12\x16\n\x0ewebhook_source\x18\x08 \x01(\t\x12\x30\n\x0fwebhook_payload\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x0foutput_contexts\x18\n \x03(\x0b\x32#.google.cloud.dialogflow.v2.Context\x12\x32\n\x06intent\x18\x0b \x01(\x0b\x32".google.cloud.dialogflow.v2.Intent\x12#\n\x1bintent_detection_confidence\x18\x0c \x01(\x02\x12\x30\n\x0f\x64iagnostic_info\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12V\n\x19sentiment_analysis_result\x18\x11 \x01(\x0b\x32\x33.google.cloud.dialogflow.v2.SentimentAnalysisResult"\x9c\x03\n\x1cStreamingDetectIntentRequest\x12:\n\x07session\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!dialogflow.googleapis.com/Session\x12\x41\n\x0cquery_params\x18\x02 \x01(\x0b\x32+.google.cloud.dialogflow.v2.QueryParameters\x12@\n\x0bquery_input\x18\x03 \x01(\x0b\x32&.google.cloud.dialogflow.v2.QueryInputB\x03\xe0\x41\x02\x12\x1c\n\x10single_utterance\x18\x04 \x01(\x08\x42\x02\x18\x01\x12J\n\x13output_audio_config\x18\x05 \x01(\x0b\x32-.google.cloud.dialogflow.v2.OutputAudioConfig\x12<\n\x18output_audio_config_mask\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0binput_audio\x18\x06 \x01(\x0c"\xd5\x02\n\x1dStreamingDetectIntentResponse\x12\x13\n\x0bresponse_id\x18\x01 \x01(\t\x12R\n\x12recognition_result\x18\x02 \x01(\x0b\x32\x36.google.cloud.dialogflow.v2.StreamingRecognitionResult\x12=\n\x0cquery_result\x18\x03 \x01(\x0b\x32\'.google.cloud.dialogflow.v2.QueryResult\x12*\n\x0ewebhook_status\x18\x04 \x01(\x0b\x32\x12.google.rpc.Status\x12\x14\n\x0coutput_audio\x18\x05 \x01(\x0c\x12J\n\x13output_audio_config\x18\x06 \x01(\x0b\x32-.google.cloud.dialogflow.v2.OutputAudioConfig"\x86\x03\n\x1aStreamingRecognitionResult\x12X\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x42.google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType\x12\x12\n\ntranscript\x18\x02 \x01(\t\x12\x10\n\x08is_final\x18\x03 \x01(\x08\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12\x44\n\x10speech_word_info\x18\x07 \x03(\x0b\x32*.google.cloud.dialogflow.v2.SpeechWordInfo\x12\x34\n\x11speech_end_offset\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration"X\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nTRANSCRIPT\x10\x01\x12\x1b\n\x17\x45ND_OF_SINGLE_UTTERANCE\x10\x02":\n\tTextInput\x12\x11\n\x04text\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x02"h\n\nEventInput\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12+\n\nparameters\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x02"F\n\x1eSentimentAnalysisRequestConfig\x12$\n\x1c\x61nalyze_query_text_sentiment\x18\x01 \x01(\x08"^\n\x17SentimentAnalysisResult\x12\x43\n\x14query_text_sentiment\x18\x01 \x01(\x0b\x32%.google.cloud.dialogflow.v2.Sentiment"-\n\tSentiment\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x11\n\tmagnitude\x18\x02 \x01(\x02\x32\xbc\x04\n\x08Sessions\x12\xa0\x02\n\x0c\x44\x65tectIntent\x12/.google.cloud.dialogflow.v2.DetectIntentRequest\x1a\x30.google.cloud.dialogflow.v2.DetectIntentResponse"\xac\x01\x82\xd3\xe4\x93\x02\x8f\x01"6/v2/{session=projects/*/agent/sessions/*}:detectIntent:\x01*ZR"M/v2/{session=projects/*/agent/environments/*/users/*/sessions/*}:detectIntent:\x01*\xda\x41\x13session,query_input\x12\x92\x01\n\x15StreamingDetectIntent\x12\x38.google.cloud.dialogflow.v2.StreamingDetectIntentRequest\x1a\x39.google.cloud.dialogflow.v2.StreamingDetectIntentResponse"\x00(\x01\x30\x01\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xc4\x02\n\x1e\x63om.google.cloud.dialogflow.v2B\x0cSessionProtoP\x01ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1aGoogle.Cloud.Dialogflow.V2\xea\x41\xa5\x01\n!dialogflow.googleapis.com/Session\x12+projects/{project}/agent/sessions/{session}\x12Sprojects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__entity__type__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
        google_dot_type_dot_latlng__pb2.DESCRIPTOR,
    ],
)


_STREAMINGRECOGNITIONRESULT_MESSAGETYPE = _descriptor.EnumDescriptor(
    name="MessageType",
    full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="MESSAGE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TRANSCRIPT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="END_OF_SINGLE_UTTERANCE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3485,
    serialized_end=3573,
)
_sym_db.RegisterEnumDescriptor(_STREAMINGRECOGNITIONRESULT_MESSAGETYPE)


_DETECTINTENTREQUEST = _descriptor.Descriptor(
    name="DetectIntentRequest",
    full_name="google.cloud.dialogflow.v2.DetectIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="session",
            full_name="google.cloud.dialogflow.v2.DetectIntentRequest.session",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\n!dialogflow.googleapis.com/Session",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_params",
            full_name="google.cloud.dialogflow.v2.DetectIntentRequest.query_params",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_input",
            full_name="google.cloud.dialogflow.v2.DetectIntentRequest.query_input",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio_config",
            full_name="google.cloud.dialogflow.v2.DetectIntentRequest.output_audio_config",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio_config_mask",
            full_name="google.cloud.dialogflow.v2.DetectIntentRequest.output_audio_config_mask",
            index=4,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="input_audio",
            full_name="google.cloud.dialogflow.v2.DetectIntentRequest.input_audio",
            index=5,
            number=5,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=549,
    serialized_end=922,
)


_DETECTINTENTRESPONSE = _descriptor.Descriptor(
    name="DetectIntentResponse",
    full_name="google.cloud.dialogflow.v2.DetectIntentResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="response_id",
            full_name="google.cloud.dialogflow.v2.DetectIntentResponse.response_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_result",
            full_name="google.cloud.dialogflow.v2.DetectIntentResponse.query_result",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="webhook_status",
            full_name="google.cloud.dialogflow.v2.DetectIntentResponse.webhook_status",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio",
            full_name="google.cloud.dialogflow.v2.DetectIntentResponse.output_audio",
            index=3,
            number=4,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio_config",
            full_name="google.cloud.dialogflow.v2.DetectIntentResponse.output_audio_config",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=925,
    serialized_end=1173,
)


_QUERYPARAMETERS = _descriptor.Descriptor(
    name="QueryParameters",
    full_name="google.cloud.dialogflow.v2.QueryParameters",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time_zone",
            full_name="google.cloud.dialogflow.v2.QueryParameters.time_zone",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="geo_location",
            full_name="google.cloud.dialogflow.v2.QueryParameters.geo_location",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="contexts",
            full_name="google.cloud.dialogflow.v2.QueryParameters.contexts",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reset_contexts",
            full_name="google.cloud.dialogflow.v2.QueryParameters.reset_contexts",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="session_entity_types",
            full_name="google.cloud.dialogflow.v2.QueryParameters.session_entity_types",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.dialogflow.v2.QueryParameters.payload",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sentiment_analysis_request_config",
            full_name="google.cloud.dialogflow.v2.QueryParameters.sentiment_analysis_request_config",
            index=6,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1176,
    serialized_end=1556,
)


_QUERYINPUT = _descriptor.Descriptor(
    name="QueryInput",
    full_name="google.cloud.dialogflow.v2.QueryInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="audio_config",
            full_name="google.cloud.dialogflow.v2.QueryInput.audio_config",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2.QueryInput.text",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="event",
            full_name="google.cloud.dialogflow.v2.QueryInput.event",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="input",
            full_name="google.cloud.dialogflow.v2.QueryInput.input",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=1559,
    serialized_end=1762,
)


_QUERYRESULT = _descriptor.Descriptor(
    name="QueryResult",
    full_name="google.cloud.dialogflow.v2.QueryResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query_text",
            full_name="google.cloud.dialogflow.v2.QueryResult.query_text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2.QueryResult.language_code",
            index=1,
            number=15,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="speech_recognition_confidence",
            full_name="google.cloud.dialogflow.v2.QueryResult.speech_recognition_confidence",
            index=2,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="action",
            full_name="google.cloud.dialogflow.v2.QueryResult.action",
            index=3,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="google.cloud.dialogflow.v2.QueryResult.parameters",
            index=4,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="all_required_params_present",
            full_name="google.cloud.dialogflow.v2.QueryResult.all_required_params_present",
            index=5,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fulfillment_text",
            full_name="google.cloud.dialogflow.v2.QueryResult.fulfillment_text",
            index=6,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fulfillment_messages",
            full_name="google.cloud.dialogflow.v2.QueryResult.fulfillment_messages",
            index=7,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="webhook_source",
            full_name="google.cloud.dialogflow.v2.QueryResult.webhook_source",
            index=8,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="webhook_payload",
            full_name="google.cloud.dialogflow.v2.QueryResult.webhook_payload",
            index=9,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_contexts",
            full_name="google.cloud.dialogflow.v2.QueryResult.output_contexts",
            index=10,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent",
            full_name="google.cloud.dialogflow.v2.QueryResult.intent",
            index=11,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_detection_confidence",
            full_name="google.cloud.dialogflow.v2.QueryResult.intent_detection_confidence",
            index=12,
            number=12,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="diagnostic_info",
            full_name="google.cloud.dialogflow.v2.QueryResult.diagnostic_info",
            index=13,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sentiment_analysis_result",
            full_name="google.cloud.dialogflow.v2.QueryResult.sentiment_analysis_result",
            index=14,
            number=17,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1765,
    serialized_end=2421,
)


_STREAMINGDETECTINTENTREQUEST = _descriptor.Descriptor(
    name="StreamingDetectIntentRequest",
    full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="session",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.session",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\n!dialogflow.googleapis.com/Session",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_params",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.query_params",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_input",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.query_input",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="single_utterance",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.single_utterance",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio_config",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.output_audio_config",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio_config_mask",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.output_audio_config_mask",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="input_audio",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentRequest.input_audio",
            index=6,
            number=6,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2424,
    serialized_end=2836,
)


_STREAMINGDETECTINTENTRESPONSE = _descriptor.Descriptor(
    name="StreamingDetectIntentResponse",
    full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="response_id",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse.response_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="recognition_result",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse.recognition_result",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_result",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse.query_result",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="webhook_status",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse.webhook_status",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse.output_audio",
            index=4,
            number=5,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_audio_config",
            full_name="google.cloud.dialogflow.v2.StreamingDetectIntentResponse.output_audio_config",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2839,
    serialized_end=3180,
)


_STREAMINGRECOGNITIONRESULT = _descriptor.Descriptor(
    name="StreamingRecognitionResult",
    full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message_type",
            full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.message_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="transcript",
            full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.transcript",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_final",
            full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.is_final",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="confidence",
            full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.confidence",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="speech_word_info",
            full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.speech_word_info",
            index=4,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="speech_end_offset",
            full_name="google.cloud.dialogflow.v2.StreamingRecognitionResult.speech_end_offset",
            index=5,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_STREAMINGRECOGNITIONRESULT_MESSAGETYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3183,
    serialized_end=3573,
)


_TEXTINPUT = _descriptor.Descriptor(
    name="TextInput",
    full_name="google.cloud.dialogflow.v2.TextInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2.TextInput.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2.TextInput.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3575,
    serialized_end=3633,
)


_EVENTINPUT = _descriptor.Descriptor(
    name="EventInput",
    full_name="google.cloud.dialogflow.v2.EventInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2.EventInput.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="google.cloud.dialogflow.v2.EventInput.parameters",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2.EventInput.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3635,
    serialized_end=3739,
)


_SENTIMENTANALYSISREQUESTCONFIG = _descriptor.Descriptor(
    name="SentimentAnalysisRequestConfig",
    full_name="google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analyze_query_text_sentiment",
            full_name="google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.analyze_query_text_sentiment",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3741,
    serialized_end=3811,
)


_SENTIMENTANALYSISRESULT = _descriptor.Descriptor(
    name="SentimentAnalysisResult",
    full_name="google.cloud.dialogflow.v2.SentimentAnalysisResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="query_text_sentiment",
            full_name="google.cloud.dialogflow.v2.SentimentAnalysisResult.query_text_sentiment",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3813,
    serialized_end=3907,
)


_SENTIMENT = _descriptor.Descriptor(
    name="Sentiment",
    full_name="google.cloud.dialogflow.v2.Sentiment",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="score",
            full_name="google.cloud.dialogflow.v2.Sentiment.score",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="magnitude",
            full_name="google.cloud.dialogflow.v2.Sentiment.magnitude",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3909,
    serialized_end=3954,
)

_DETECTINTENTREQUEST.fields_by_name["query_params"].message_type = _QUERYPARAMETERS
_DETECTINTENTREQUEST.fields_by_name["query_input"].message_type = _QUERYINPUT
_DETECTINTENTREQUEST.fields_by_name[
    "output_audio_config"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2._OUTPUTAUDIOCONFIG
)
_DETECTINTENTREQUEST.fields_by_name[
    "output_audio_config_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_DETECTINTENTRESPONSE.fields_by_name["query_result"].message_type = _QUERYRESULT
_DETECTINTENTRESPONSE.fields_by_name[
    "webhook_status"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DETECTINTENTRESPONSE.fields_by_name[
    "output_audio_config"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2._OUTPUTAUDIOCONFIG
)
_QUERYPARAMETERS.fields_by_name[
    "geo_location"
].message_type = google_dot_type_dot_latlng__pb2._LATLNG
_QUERYPARAMETERS.fields_by_name[
    "contexts"
].message_type = google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2._CONTEXT
_QUERYPARAMETERS.fields_by_name[
    "session_entity_types"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__entity__type__pb2._SESSIONENTITYTYPE
)
_QUERYPARAMETERS.fields_by_name[
    "payload"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_QUERYPARAMETERS.fields_by_name[
    "sentiment_analysis_request_config"
].message_type = _SENTIMENTANALYSISREQUESTCONFIG
_QUERYINPUT.fields_by_name[
    "audio_config"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2._INPUTAUDIOCONFIG
)
_QUERYINPUT.fields_by_name["text"].message_type = _TEXTINPUT
_QUERYINPUT.fields_by_name["event"].message_type = _EVENTINPUT
_QUERYINPUT.oneofs_by_name["input"].fields.append(
    _QUERYINPUT.fields_by_name["audio_config"]
)
_QUERYINPUT.fields_by_name[
    "audio_config"
].containing_oneof = _QUERYINPUT.oneofs_by_name["input"]
_QUERYINPUT.oneofs_by_name["input"].fields.append(_QUERYINPUT.fields_by_name["text"])
_QUERYINPUT.fields_by_name["text"].containing_oneof = _QUERYINPUT.oneofs_by_name[
    "input"
]
_QUERYINPUT.oneofs_by_name["input"].fields.append(_QUERYINPUT.fields_by_name["event"])
_QUERYINPUT.fields_by_name["event"].containing_oneof = _QUERYINPUT.oneofs_by_name[
    "input"
]
_QUERYRESULT.fields_by_name[
    "parameters"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_QUERYRESULT.fields_by_name[
    "fulfillment_messages"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2._INTENT_MESSAGE
)
_QUERYRESULT.fields_by_name[
    "webhook_payload"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_QUERYRESULT.fields_by_name[
    "output_contexts"
].message_type = google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2._CONTEXT
_QUERYRESULT.fields_by_name[
    "intent"
].message_type = google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2._INTENT
_QUERYRESULT.fields_by_name[
    "diagnostic_info"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_QUERYRESULT.fields_by_name[
    "sentiment_analysis_result"
].message_type = _SENTIMENTANALYSISRESULT
_STREAMINGDETECTINTENTREQUEST.fields_by_name[
    "query_params"
].message_type = _QUERYPARAMETERS
_STREAMINGDETECTINTENTREQUEST.fields_by_name["query_input"].message_type = _QUERYINPUT
_STREAMINGDETECTINTENTREQUEST.fields_by_name[
    "output_audio_config"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2._OUTPUTAUDIOCONFIG
)
_STREAMINGDETECTINTENTREQUEST.fields_by_name[
    "output_audio_config_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_STREAMINGDETECTINTENTRESPONSE.fields_by_name[
    "recognition_result"
].message_type = _STREAMINGRECOGNITIONRESULT
_STREAMINGDETECTINTENTRESPONSE.fields_by_name[
    "query_result"
].message_type = _QUERYRESULT
_STREAMINGDETECTINTENTRESPONSE.fields_by_name[
    "webhook_status"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_STREAMINGDETECTINTENTRESPONSE.fields_by_name[
    "output_audio_config"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2._OUTPUTAUDIOCONFIG
)
_STREAMINGRECOGNITIONRESULT.fields_by_name[
    "message_type"
].enum_type = _STREAMINGRECOGNITIONRESULT_MESSAGETYPE
_STREAMINGRECOGNITIONRESULT.fields_by_name[
    "speech_word_info"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_audio__config__pb2._SPEECHWORDINFO
)
_STREAMINGRECOGNITIONRESULT.fields_by_name[
    "speech_end_offset"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMINGRECOGNITIONRESULT_MESSAGETYPE.containing_type = _STREAMINGRECOGNITIONRESULT
_EVENTINPUT.fields_by_name[
    "parameters"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SENTIMENTANALYSISRESULT.fields_by_name[
    "query_text_sentiment"
].message_type = _SENTIMENT
DESCRIPTOR.message_types_by_name["DetectIntentRequest"] = _DETECTINTENTREQUEST
DESCRIPTOR.message_types_by_name["DetectIntentResponse"] = _DETECTINTENTRESPONSE
DESCRIPTOR.message_types_by_name["QueryParameters"] = _QUERYPARAMETERS
DESCRIPTOR.message_types_by_name["QueryInput"] = _QUERYINPUT
DESCRIPTOR.message_types_by_name["QueryResult"] = _QUERYRESULT
DESCRIPTOR.message_types_by_name[
    "StreamingDetectIntentRequest"
] = _STREAMINGDETECTINTENTREQUEST
DESCRIPTOR.message_types_by_name[
    "StreamingDetectIntentResponse"
] = _STREAMINGDETECTINTENTRESPONSE
DESCRIPTOR.message_types_by_name[
    "StreamingRecognitionResult"
] = _STREAMINGRECOGNITIONRESULT
DESCRIPTOR.message_types_by_name["TextInput"] = _TEXTINPUT
DESCRIPTOR.message_types_by_name["EventInput"] = _EVENTINPUT
DESCRIPTOR.message_types_by_name[
    "SentimentAnalysisRequestConfig"
] = _SENTIMENTANALYSISREQUESTCONFIG
DESCRIPTOR.message_types_by_name["SentimentAnalysisResult"] = _SENTIMENTANALYSISRESULT
DESCRIPTOR.message_types_by_name["Sentiment"] = _SENTIMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DetectIntentRequest = _reflection.GeneratedProtocolMessageType(
    "DetectIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DETECTINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """The request to detect user’s intent.
  
  Attributes:
      session:
          Required. The name of the session this query is sent to.
          Format: ``projects/<Project ID>/agent/sessions/<Session ID>``,
          or ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified, we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we are using “-”. It’s up to
          the API caller to choose an appropriate ``Session ID`` and
          ``User Id``. They can be a random number or some type of user
          and session identifiers (preferably hashed). The length of the
          ``Session ID`` and ``User ID`` must not exceed 36 characters.
          For more information, see the `API interactions guide
          <https://cloud.google.com/dialogflow/docs/api-overview>`__.
      query_params:
          The parameters of this query.
      query_input:
          Required. The input specification. It can be set to:  1. an
          audio config which instructs the speech recognizer how to
          process    the speech audio,  2. a conversational query in the
          form of text, or  3. an event that specifies which intent to
          trigger.
      output_audio_config:
          Instructs the speech synthesizer how to generate the output
          audio. If this field is not set and agent-level speech
          synthesizer is not configured, no output audio is generated.
      output_audio_config_mask:
          Mask for [output_audio_config][google.cloud.dialogflow.v2.Dete
          ctIntentRequest.output_audio_config] indicating which settings
          in this request-level config should override speech
          synthesizer settings defined at agent-level.  If unspecified
          or empty, [output_audio_config][google.cloud.dialogflow.v2.Det
          ectIntentRequest.output_audio_config] replaces the agent-level
          config in its entirety.
      input_audio:
          The natural language speech audio to be processed. This field
          should be populated iff ``query_input`` is set to an input
          audio config. A single request can contain up to 1 minute of
          speech audio data.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.DetectIntentRequest)
    },
)
_sym_db.RegisterMessage(DetectIntentRequest)

DetectIntentResponse = _reflection.GeneratedProtocolMessageType(
    "DetectIntentResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DETECTINTENTRESPONSE,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """The message returned from the DetectIntent method.
  
  Attributes:
      response_id:
          The unique identifier of the response. It can be used to
          locate a response in the training example set or for reporting
          issues.
      query_result:
          The selected results of the conversational query or event
          processing. See ``alternative_query_results`` for additional
          potential results.
      webhook_status:
          Specifies the status of the webhook request.
      output_audio:
          The audio data bytes encoded as specified in the request.
          Note: The output audio is generated based on the values of
          default platform text responses found in the
          ``query_result.fulfillment_messages`` field. If multiple
          default text responses exist, they will be concatenated when
          generating audio. If no default platform text responses exist,
          the generated audio content will be empty.  In some scenarios,
          multiple output audio fields may be present in the response
          structure. In these cases, only the top-most-level audio
          output has content.
      output_audio_config:
          The config used by the speech synthesizer to generate the
          output audio.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.DetectIntentResponse)
    },
)
_sym_db.RegisterMessage(DetectIntentResponse)

QueryParameters = _reflection.GeneratedProtocolMessageType(
    "QueryParameters",
    (_message.Message,),
    {
        "DESCRIPTOR": _QUERYPARAMETERS,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Represents the parameters of the conversational query.
  
  Attributes:
      time_zone:
          The time zone of this conversational query from the `time zone
          database <https://www.iana.org/time-zones>`__, e.g.,
          America/New_York, Europe/Paris. If not provided, the time zone
          specified in agent settings is used.
      geo_location:
          The geo location of this conversational query.
      contexts:
          The collection of contexts to be activated before this query
          is executed.
      reset_contexts:
          Specifies whether to delete all contexts in the current
          session before the new ones are activated.
      session_entity_types:
          Additional session entity types to replace or extend developer
          entity types with. The entity synonyms apply to all languages
          and persist for the session of this query.
      payload:
          This field can be used to pass custom data to your webhook.
          Arbitrary JSON objects are supported. If supplied, the value
          is used to populate the
          ``WebhookRequest.original_detect_intent_request.payload``
          field sent to your webhook.
      sentiment_analysis_request_config:
          Configures the type of sentiment analysis to perform. If not
          provided, sentiment analysis is not performed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.QueryParameters)
    },
)
_sym_db.RegisterMessage(QueryParameters)

QueryInput = _reflection.GeneratedProtocolMessageType(
    "QueryInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _QUERYINPUT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Represents the query input. It can contain either:  1. An audio config
  which instructs the speech recognizer how to process    the speech
  audio.  2. A conversational query in the form of text,.  3. An event
  that specifies which intent to trigger.
  
  Attributes:
      input:
          Required. The input specification.
      audio_config:
          Instructs the speech recognizer how to process the speech
          audio.
      text:
          The natural language text to be processed.
      event:
          The event to be processed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.QueryInput)
    },
)
_sym_db.RegisterMessage(QueryInput)

QueryResult = _reflection.GeneratedProtocolMessageType(
    "QueryResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _QUERYRESULT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Represents the result of conversational query or event processing.
  
  Attributes:
      query_text:
          The original conversational query text:  -  If natural
          language text was provided as input, ``query_text``
          contains a copy of the input. -  If natural language speech
          audio was provided as input,    ``query_text`` contains the
          speech recognition result. If speech    recognizer produced
          multiple alternatives, a particular one is    picked. -  If
          automatic spell correction is enabled, ``query_text`` will
          contain    the corrected user input.
      language_code:
          The language that was triggered during intent detection. See
          `Language Support <https://cloud.google.com/dialogflow/docs/re
          ference/language>`__ for a list of the currently supported
          language codes.
      speech_recognition_confidence:
          The Speech recognition confidence between 0.0 and 1.0. A
          higher number indicates an estimated greater likelihood that
          the recognized words are correct. The default of 0.0 is a
          sentinel value indicating that confidence was not set.  This
          field is not guaranteed to be accurate or set. In particular
          this field isn’t set for StreamingDetectIntent since the
          streaming endpoint has separate confidence estimates per
          portion of the audio in StreamingRecognitionResult.
      action:
          The action name from the matched intent.
      parameters:
          The collection of extracted parameters.  Depending on your
          protocol or client library language, this is a map,
          associative array, symbol table, dictionary, or JSON object
          composed of a collection of (MapKey, MapValue) pairs:  -
          MapKey type: string -  MapKey value: parameter name -
          MapValue type:     -  If parameter’s entity type is a
          composite entity: map    -  Else: string or number, depending
          on parameter value type  -  MapValue value:     -  If
          parameter’s entity type is a composite entity: map from
          composite entity property names to property values    -  Else:
          parameter value
      all_required_params_present:
          This field is set to:  -  ``false`` if the matched intent has
          required parameters and not all    of the required parameter
          values have been collected. -  ``true`` if all required
          parameter values have been collected, or if    the matched
          intent doesn’t contain any required parameters.
      fulfillment_text:
          The text to be pronounced to the user or shown on the screen.
          Note: This is a legacy field, ``fulfillment_messages`` should
          be preferred.
      fulfillment_messages:
          The collection of rich messages to present to the user.
      webhook_source:
          If the query was fulfilled by a webhook call, this field is
          set to the value of the ``source`` field returned in the
          webhook response.
      webhook_payload:
          If the query was fulfilled by a webhook call, this field is
          set to the value of the ``payload`` field returned in the
          webhook response.
      output_contexts:
          The collection of output contexts. If applicable,
          ``output_contexts.parameters`` contains entries with name
          ``<parameter name>.original`` containing the original
          parameter values before the query.
      intent:
          The intent that matched the conversational query. Some, not
          all fields are filled in this message, including but not
          limited to: ``name``, ``display_name``, ``end_interaction``
          and ``is_fallback``.
      intent_detection_confidence:
          The intent detection confidence. Values range from 0.0
          (completely uncertain) to 1.0 (completely certain). This value
          is for informational purpose only and is only used to help
          match the best intent within the classification threshold.
          This value may change for the same end-user expression at any
          time due to a model retraining or change in implementation. If
          there are ``multiple knowledge_answers`` messages, this value
          is set to the greatest ``knowledgeAnswers.match_confidence``
          value in the list.
      diagnostic_info:
          Free-form diagnostic information for the associated detect
          intent request. The fields of this data can change without
          notice, so you should not write code that depends on its
          structure. The data may contain:  -  webhook call latency -
          webhook errors
      sentiment_analysis_result:
          The sentiment analysis result, which depends on the
          ``sentiment_analysis_request_config`` specified in the
          request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.QueryResult)
    },
)
_sym_db.RegisterMessage(QueryResult)

StreamingDetectIntentRequest = _reflection.GeneratedProtocolMessageType(
    "StreamingDetectIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGDETECTINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """The top-level message sent by the client to the [Sessions.StreamingDet
  ectIntent][google.cloud.dialogflow.v2.Sessions.StreamingDetectIntent]
  method.  Multiple request messages should be sent in order:  1. The
  first message must contain    [session][google.cloud.dialogflow.v2.Str
  eamingDetectIntentRequest.session],    [query_input][google.cloud.dial
  ogflow.v2.StreamingDetectIntentRequest.query_input]    plus optionally
  [query_params][google.cloud.dialogflow.v2.StreamingDetectIntentRequest
  .query_params].    If the client wants to receive an audio response,
  it should also    contain    [output_audio_config][google.cloud.dialog
  flow.v2.StreamingDetectIntentRequest.output_audio_config].    The
  message must not contain    [input_audio][google.cloud.dialogflow.v2.S
  treamingDetectIntentRequest.input_audio]. 2. If    [query_input][googl
  e.cloud.dialogflow.v2.StreamingDetectIntentRequest.query_input]    was
  set to    [query_input.audio_config][google.cloud.dialogflow.v2.InputA
  udioConfig],    all subsequent messages must contain    [input_audio][
  google.cloud.dialogflow.v2.StreamingDetectIntentRequest.input_audio]
  to continue with Speech recognition. If you decide to rather detect
  an intent from text input after you already started Speech
  recognition, please send a message with
  [query_input.text][google.cloud.dialogflow.v2.QueryInput.text].
  However, note that:     -  Dialogflow will bill you for the audio
  duration so far.    -  Dialogflow discards all Speech recognition
  results in favor of the       input text.    -  Dialogflow will use
  the language code from the first message.  After you sent all input,
  you must half-close or abort the request stream.
  
  Attributes:
      session:
          Required. The name of the session the query is sent to. Format
          of the session name: ``projects/<Project
          ID>/agent/sessions/<Session ID>``, or ``projects/<Project
          ID>/agent/environments/<Environment ID>/users/<User
          ID>/sessions/<Session ID>``. If ``Environment ID`` is not
          specified, we assume default ‘draft’ environment. If ``User
          ID`` is not specified, we are using “-”. It’s up to the API
          caller to choose an appropriate ``Session ID`` and ``User
          Id``. They can be a random number or some type of user and
          session identifiers (preferably hashed). The length of the
          ``Session ID`` and ``User ID`` must not exceed 36 characters.
          For more information, see the `API interactions guide
          <https://cloud.google.com/dialogflow/docs/api-overview>`__.
      query_params:
          The parameters of this query.
      query_input:
          Required. The input specification. It can be set to:  1. an
          audio config which instructs the speech recognizer how to
          process    the speech audio,  2. a conversational query in the
          form of text, or  3. an event that specifies which intent to
          trigger.
      single_utterance:
          Please use [InputAudioConfig.single_utterance][google.cloud.di
          alogflow.v2.InputAudioConfig.single_utterance] instead. If
          ``false`` (default), recognition does not cease until the
          client closes the stream. If ``true``, the recognizer will
          detect a single spoken utterance in input audio. Recognition
          ceases when it detects the audio’s voice has stopped or
          paused. In this case, once a detected intent is received, the
          client should close the stream and start a new request with a
          new stream as needed. This setting is ignored when
          ``query_input`` is a piece of text or an event.
      output_audio_config:
          Instructs the speech synthesizer how to generate the output
          audio. If this field is not set and agent-level speech
          synthesizer is not configured, no output audio is generated.
      output_audio_config_mask:
          Mask for [output_audio_config][google.cloud.dialogflow.v2.Stre
          amingDetectIntentRequest.output_audio_config] indicating which
          settings in this request-level config should override speech
          synthesizer settings defined at agent-level.  If unspecified
          or empty, [output_audio_config][google.cloud.dialogflow.v2.Str
          eamingDetectIntentRequest.output_audio_config] replaces the
          agent-level config in its entirety.
      input_audio:
          The input audio content to be recognized. Must be sent if
          ``query_input`` was set to a streaming input audio config. The
          complete audio over all streaming messages must not exceed 1
          minute.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.StreamingDetectIntentRequest)
    },
)
_sym_db.RegisterMessage(StreamingDetectIntentRequest)

StreamingDetectIntentResponse = _reflection.GeneratedProtocolMessageType(
    "StreamingDetectIntentResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGDETECTINTENTRESPONSE,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """The top-level message returned from the ``StreamingDetectIntent``
  method.  Multiple response messages can be returned in order:  1. If
  the input was set to streaming audio, the first one or more
  messages contain ``recognition_result``. Each ``recognition_result``
  represents a more complete transcript of what the user said. The last
  ``recognition_result`` has ``is_final`` set to ``true``.  2. The next
  message contains ``response_id``, ``query_result`` and    optionally
  ``webhook_status`` if a WebHook was called.
  
  Attributes:
      response_id:
          The unique identifier of the response. It can be used to
          locate a response in the training example set or for reporting
          issues.
      recognition_result:
          The result of speech recognition.
      query_result:
          The result of the conversational query or event processing.
      webhook_status:
          Specifies the status of the webhook request.
      output_audio:
          The audio data bytes encoded as specified in the request.
          Note: The output audio is generated based on the values of
          default platform text responses found in the
          ``query_result.fulfillment_messages`` field. If multiple
          default text responses exist, they will be concatenated when
          generating audio. If no default platform text responses exist,
          the generated audio content will be empty.  In some scenarios,
          multiple output audio fields may be present in the response
          structure. In these cases, only the top-most-level audio
          output has content.
      output_audio_config:
          The config used by the speech synthesizer to generate the
          output audio.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.StreamingDetectIntentResponse)
    },
)
_sym_db.RegisterMessage(StreamingDetectIntentResponse)

StreamingRecognitionResult = _reflection.GeneratedProtocolMessageType(
    "StreamingRecognitionResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGRECOGNITIONRESULT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Contains a speech recognition result corresponding to a portion of the
  audio that is currently being processed or an indication that this is
  the end of the single requested utterance.  Example:  1. transcript:
  “tube”  2. transcript: “to be a”  3. transcript: “to be”  4.
  transcript: “to be or not to be” is_final: true  5. transcript: "
  that’s"  6. transcript: " that is"  7. message_type:
  ``END_OF_SINGLE_UTTERANCE``  8. transcript: " that is the question"
  is_final: true  Only two of the responses contain final results (#4
  and #8 indicated by ``is_final: true``). Concatenating these generates
  the full transcript: “to be or not to be that is the question”.  In
  each response we populate:  -  for ``TRANSCRIPT``: ``transcript`` and
  possibly ``is_final``.  -  for ``END_OF_SINGLE_UTTERANCE``: only
  ``message_type``.
  
  Attributes:
      message_type:
          Type of the result message.
      transcript:
          Transcript text representing the words that the user spoke.
          Populated if and only if ``message_type`` = ``TRANSCRIPT``.
      is_final:
          If ``false``, the ``StreamingRecognitionResult`` represents an
          interim result that may change. If ``true``, the recognizer
          will not return any further hypotheses about this piece of the
          audio. May only be populated for ``message_type`` =
          ``TRANSCRIPT``.
      confidence:
          The Speech confidence between 0.0 and 1.0 for the current
          portion of audio. A higher number indicates an estimated
          greater likelihood that the recognized words are correct. The
          default of 0.0 is a sentinel value indicating that confidence
          was not set.  This field is typically only provided if
          ``is_final`` is true and you should not rely on it being
          accurate or even set.
      speech_word_info:
          Word-specific information for the words recognized by Speech
          in [transcript][google.cloud.dialogflow.v2.StreamingRecognitio
          nResult.transcript]. Populated if and only if ``message_type``
          = ``TRANSCRIPT`` and [InputAudioConfig.enable_word_info] is
          set.
      speech_end_offset:
          Time offset of the end of this Speech recognition result
          relative to the beginning of the audio. Only populated for
          ``message_type`` = ``TRANSCRIPT``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.StreamingRecognitionResult)
    },
)
_sym_db.RegisterMessage(StreamingRecognitionResult)

TextInput = _reflection.GeneratedProtocolMessageType(
    "TextInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _TEXTINPUT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Represents the natural language text to be processed.
  
  Attributes:
      text:
          Required. The UTF-8 encoded natural language text to be
          processed. Text length must not exceed 256 characters.
      language_code:
          Required. The language of this conversational query. See
          `Language Support <https://cloud.google.com/dialogflow/docs/re
          ference/language>`__ for a list of the currently supported
          language codes. Note that queries in the same session do not
          necessarily need to specify the same language.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.TextInput)
    },
)
_sym_db.RegisterMessage(TextInput)

EventInput = _reflection.GeneratedProtocolMessageType(
    "EventInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVENTINPUT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Events allow for matching intents by event name instead of the natural
  language input. For instance, input ``<event: { name: "welcome_event",
  parameters: { name: "Sam" } }>`` can trigger a personalized welcome
  response. The parameter ``name`` may be used by the agent in the
  response: ``"Hello #welcome_event.name! What can I do for you
  today?"``.
  
  Attributes:
      name:
          Required. The unique identifier of the event.
      parameters:
          The collection of parameters associated with the event.
          Depending on your protocol or client library language, this is
          a map, associative array, symbol table, dictionary, or JSON
          object composed of a collection of (MapKey, MapValue) pairs:
          -  MapKey type: string -  MapKey value: parameter name -
          MapValue type:     -  If parameter’s entity type is a
          composite entity: map    -  Else: string or number, depending
          on parameter value type  -  MapValue value:     -  If
          parameter’s entity type is a composite entity: map from
          composite entity property names to property values    -  Else:
          parameter value
      language_code:
          Required. The language of this query. See `Language Support <h
          ttps://cloud.google.com/dialogflow/docs/reference/language>`__
          for a list of the currently supported language codes. Note
          that queries in the same session do not necessarily need to
          specify the same language.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.EventInput)
    },
)
_sym_db.RegisterMessage(EventInput)

SentimentAnalysisRequestConfig = _reflection.GeneratedProtocolMessageType(
    "SentimentAnalysisRequestConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _SENTIMENTANALYSISREQUESTCONFIG,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """Configures the types of sentiment analysis to perform.
  
  Attributes:
      analyze_query_text_sentiment:
          Instructs the service to perform sentiment analysis on
          ``query_text``. If not provided, sentiment analysis is not
          performed on ``query_text``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig)
    },
)
_sym_db.RegisterMessage(SentimentAnalysisRequestConfig)

SentimentAnalysisResult = _reflection.GeneratedProtocolMessageType(
    "SentimentAnalysisResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _SENTIMENTANALYSISRESULT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """The result of sentiment analysis. Sentiment analysis inspects user
  input and identifies the prevailing subjective opinion, especially to
  determine a user’s attitude as positive, negative, or neutral. For [Pa
  rticipants.AnalyzeContent][google.cloud.dialogflow.v2.Participants.Ana
  lyzeContent], it needs to be configured in [DetectIntentRequest.query_
  params][google.cloud.dialogflow.v2.DetectIntentRequest.query_params].
  For [Participants.StreamingAnalyzeContent][google.cloud.dialogflow.v2.
  Participants.StreamingAnalyzeContent], it needs to be configured in [S
  treamingDetectIntentRequest.query_params][google.cloud.dialogflow.v2.S
  treamingDetectIntentRequest.query_params]. And for [Participants.Analy
  zeContent][google.cloud.dialogflow.v2.Participants.AnalyzeContent] and
  [Participants.StreamingAnalyzeContent][google.cloud.dialogflow.v2.Part
  icipants.StreamingAnalyzeContent], it needs to be configured in [Conve
  rsationProfile.human_agent_assistant_config][google.cloud.dialogflow.v
  2.ConversationProfile.human_agent_assistant_config]
  
  Attributes:
      query_text_sentiment:
          The sentiment analysis result for ``query_text``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.SentimentAnalysisResult)
    },
)
_sym_db.RegisterMessage(SentimentAnalysisResult)

Sentiment = _reflection.GeneratedProtocolMessageType(
    "Sentiment",
    (_message.Message,),
    {
        "DESCRIPTOR": _SENTIMENT,
        "__module__": "google.cloud.dialogflow_v2.proto.session_pb2",
        "__doc__": """The sentiment, such as positive/negative feeling or association, for a
  unit of analysis, such as the query text.
  
  Attributes:
      score:
          Sentiment score between -1.0 (negative sentiment) and 1.0
          (positive sentiment).
      magnitude:
          A non-negative number in the [0, +inf) range, which represents
          the absolute magnitude of sentiment, regardless of score
          (positive or negative).
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.Sentiment)
    },
)
_sym_db.RegisterMessage(Sentiment)


DESCRIPTOR._options = None
_DETECTINTENTREQUEST.fields_by_name["session"]._options = None
_DETECTINTENTREQUEST.fields_by_name["query_input"]._options = None
_STREAMINGDETECTINTENTREQUEST.fields_by_name["session"]._options = None
_STREAMINGDETECTINTENTREQUEST.fields_by_name["query_input"]._options = None
_STREAMINGDETECTINTENTREQUEST.fields_by_name["single_utterance"]._options = None
_TEXTINPUT.fields_by_name["text"]._options = None
_TEXTINPUT.fields_by_name["language_code"]._options = None
_EVENTINPUT.fields_by_name["name"]._options = None
_EVENTINPUT.fields_by_name["language_code"]._options = None

_SESSIONS = _descriptor.ServiceDescriptor(
    name="Sessions",
    full_name="google.cloud.dialogflow.v2.Sessions",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=3957,
    serialized_end=4529,
    methods=[
        _descriptor.MethodDescriptor(
            name="DetectIntent",
            full_name="google.cloud.dialogflow.v2.Sessions.DetectIntent",
            index=0,
            containing_service=None,
            input_type=_DETECTINTENTREQUEST,
            output_type=_DETECTINTENTRESPONSE,
            serialized_options=b'\202\323\344\223\002\217\001"6/v2/{session=projects/*/agent/sessions/*}:detectIntent:\001*ZR"M/v2/{session=projects/*/agent/environments/*/users/*/sessions/*}:detectIntent:\001*\332A\023session,query_input',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="StreamingDetectIntent",
            full_name="google.cloud.dialogflow.v2.Sessions.StreamingDetectIntent",
            index=1,
            containing_service=None,
            input_type=_STREAMINGDETECTINTENTREQUEST,
            output_type=_STREAMINGDETECTINTENTRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_SESSIONS)

DESCRIPTOR.services_by_name["Sessions"] = _SESSIONS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.rpc import status_pb2

import dialogflow_v2beta1
from dialogflow_v2beta1.proto import agent_pb2
from dialogflow_v2beta1.proto import validation_result_pb2
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestAgentsClient(object):
    def test_get_agent(self):
        # Setup Expected Response
        parent_2 = "parent21175163357"
        display_name = "displayName1615086568"
        default_language_code = "defaultLanguageCode856575222"
        time_zone = "timeZone36848094"
        description = "description-1724546052"
        avatar_uri = "avatarUri-402824826"
        enable_logging = False
        classification_threshold = 1.11581064e8
        expected_response = {
            "parent": parent_2,
            "display_name": display_name,
            "default_language_code": default_language_code,
            "time_zone": time_zone,
            "description": description,
            "avatar_uri": avatar_uri,
            "enable_logging": enable_logging,
            "classification_threshold": classification_threshold,
        }
        expected_response = agent_pb2.Agent(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.get_agent(parent)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = agent_pb2.GetAgentRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_agent_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup request
        parent = client.project_path("[PROJECT]")

        with pytest.raises(CustomException):
            client.get_agent(parent)

    def test_set_agent(self):
        # Setup Expected Response
        parent = "parent-995424086"
        display_name = "displayName1615086568"
        default_language_code = "defaultLanguageCode856575222"
        time_zone = "timeZone36848094"
        description = "description-1724546052"
        avatar_uri = "avatarUri-402824826"
        enable_logging = False
        classification_threshold = 1.11581064e8
        expected_response = {
            "parent": parent,
            "display_name": display_name,
            "default_language_code": default_language_code,
            "time_zone": time_zone,
            "description": description,
            "avatar_uri": avatar_uri,
            "enable_logging": enable_logging,
            "classification_threshold": classification_threshold,
        }
        expected_response = agent_pb2.Agent(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        agent = {}

        response = client.set_agent(agent)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = agent_pb2.SetAgentRequest(agent=agent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_set_agent_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup request
        agent = {}

        with pytest.raises(CustomException):
            client.set_agent(agent)

    def test_delete_agent(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        client.delete_agent(parent)

        assert len(channel.requests) == 1
        expected_request = agent_pb2.DeleteAgentRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_agent_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup request
        parent = client.project_path("[PROJECT]")

        with pytest.raises(CustomException):
            client.delete_agent(parent)

    def test_search_agents(self):
        # Setup Expected Response
        next_page_token = ""
        agents_element = {}
        agents = [agents_element]
        expected_response = {"next_page_token": next_page_token, "agents": agents}
        expected_response = agent_pb2.SearchAgentsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        paged_list_response = client.search_agents(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.agents[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = agent_pb2.SearchAgentsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_search_agents_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup request
        parent = client.project_path("[PROJECT]")

        paged_list_response = client.search_agents(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_train_agent(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_train_agent", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.train_agent(parent)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = agent_pb2.TrainAgentRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_train_agent_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_train_agent_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.train_agent(parent)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_export_agent(self):
        # Setup Expected Response
        agent_uri = "agentUri-1700713166"
        expected_response = {"agent_uri": agent_uri}
        expected_response = agent_pb2.ExportAgentResponse(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_export_agent", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.export_agent(parent)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = agent_pb2.ExportAgentRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_export_agent_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_export_agent_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.export_agent(parent)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_import_agent(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_import_agent", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.import_agent(parent)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = agent_pb2.ImportAgentRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_import_agent_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_import_agent_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.import_agent(parent)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_restore_agent(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_restore_agent", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.restore_agent(parent)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = agent_pb2.RestoreAgentRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_restore_agent_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_restore_agent_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.restore_agent(parent)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_get_validation_result(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = validation_result_pb2.ValidationResult(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        response = client.get_validation_result(parent)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = agent_pb2.GetValidationResultRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_validation_result_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.AgentsClient()

        # Setup request
        parent = client.project_path("[PROJECT]")

        with pytest.raises(CustomException):
            client.get_validation_result(parent)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2/proto/webhook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dialogflow_v2.proto import (
    context_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2,
)
from dialogflow_v2.proto import (
    intent_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2,
)
from dialogflow_v2.proto import (
    session_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2,
)
from dialogflow_v2.proto import (
    session_entity_type_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__entity__type__pb2,
)
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2/proto/webhook.proto",
    package="google.cloud.dialogflow.v2",
    syntax="proto3",
    serialized_options=b"\n\036com.google.cloud.dialogflow.v2B\014WebhookProtoP\001ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\370\001\001\242\002\002DF\252\002\032Google.Cloud.Dialogflow.V2",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n.google/cloud/dialogflow_v2/proto/webhook.proto\x12\x1agoogle.cloud.dialogflow.v2\x1a.google/cloud/dialogflow_v2/proto/context.proto\x1a-google/cloud/dialogflow_v2/proto/intent.proto\x1a.google/cloud/dialogflow_v2/proto/session.proto\x1a:google/cloud/dialogflow_v2/proto/session_entity_type.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto"\xd6\x01\n\x0eWebhookRequest\x12\x0f\n\x07session\x18\x04 \x01(\t\x12\x13\n\x0bresponse_id\x18\x01 \x01(\t\x12=\n\x0cquery_result\x18\x02 \x01(\x0b\x32\'.google.cloud.dialogflow.v2.QueryResult\x12_\n\x1eoriginal_detect_intent_request\x18\x03 \x01(\x0b\x32\x37.google.cloud.dialogflow.v2.OriginalDetectIntentRequest"\x80\x03\n\x0fWebhookResponse\x12\x18\n\x10\x66ulfillment_text\x18\x01 \x01(\t\x12H\n\x14\x66ulfillment_messages\x18\x02 \x03(\x0b\x32*.google.cloud.dialogflow.v2.Intent.Message\x12\x0e\n\x06source\x18\x03 \x01(\t\x12(\n\x07payload\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x0foutput_contexts\x18\x05 \x03(\x0b\x32#.google.cloud.dialogflow.v2.Context\x12\x44\n\x14\x66ollowup_event_input\x18\x06 \x01(\x0b\x32&.google.cloud.dialogflow.v2.EventInput\x12K\n\x14session_entity_types\x18\n \x03(\x0b\x32-.google.cloud.dialogflow.v2.SessionEntityType"h\n\x1bOriginalDetectIntentRequest\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07payload\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x9b\x01\n\x1e\x63om.google.cloud.dialogflow.v2B\x0cWebhookProtoP\x01ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1aGoogle.Cloud.Dialogflow.V2b\x06proto3',
    dependencies=[
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__entity__type__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_WEBHOOKREQUEST = _descriptor.Descriptor(
    name="WebhookRequest",
    full_name="google.cloud.dialogflow.v2.WebhookRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="session",
            full_name="google.cloud.dialogflow.v2.WebhookRequest.session",
            index=0,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="response_id",
            full_name="google.cloud.dialogflow.v2.WebhookRequest.response_id",
            index=1,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query_result",
            full_name="google.cloud.dialogflow.v2.WebhookRequest.query_result",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="original_detect_intent_request",
            full_name="google.cloud.dialogflow.v2.WebhookRequest.original_detect_intent_request",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=342,
    serialized_end=556,
)


_WEBHOOKRESPONSE = _descriptor.Descriptor(
    name="WebhookResponse",
    full_name="google.cloud.dialogflow.v2.WebhookResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="fulfillment_text",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.fulfillment_text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fulfillment_messages",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.fulfillment_messages",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="source",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.source",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.payload",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_contexts",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.output_contexts",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="followup_event_input",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.followup_event_input",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="session_entity_types",
            full_name="google.cloud.dialogflow.v2.WebhookResponse.session_entity_types",
            index=6,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=559,
    serialized_end=943,
)


_ORIGINALDETECTINTENTREQUEST = _descriptor.Descriptor(
    name="OriginalDetectIntentRequest",
    full_name="google.cloud.dialogflow.v2.OriginalDetectIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="source",
            full_name="google.cloud.dialogflow.v2.OriginalDetectIntentRequest.source",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="google.cloud.dialogflow.v2.OriginalDetectIntentRequest.version",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.dialogflow.v2.OriginalDetectIntentRequest.payload",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=945,
    serialized_end=1049,
)

_WEBHOOKREQUEST.fields_by_name[
    "query_result"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2._QUERYRESULT
)
_WEBHOOKREQUEST.fields_by_name[
    "original_detect_intent_request"
].message_type = _ORIGINALDETECTINTENTREQUEST
_WEBHOOKRESPONSE.fields_by_name[
    "fulfillment_messages"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2._INTENT_MESSAGE
)
_WEBHOOKRESPONSE.fields_by_name[
    "payload"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_WEBHOOKRESPONSE.fields_by_name[
    "output_contexts"
].message_type = google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_context__pb2._CONTEXT
_WEBHOOKRESPONSE.fields_by_name[
    "followup_event_input"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__pb2._EVENTINPUT
)
_WEBHOOKRESPONSE.fields_by_name[
    "session_entity_types"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_session__entity__type__pb2._SESSIONENTITYTYPE
)
_ORIGINALDETECTINTENTREQUEST.fields_by_name[
    "payload"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name["WebhookRequest"] = _WEBHOOKREQUEST
DESCRIPTOR.message_types_by_name["WebhookResponse"] = _WEBHOOKRESPONSE
DESCRIPTOR.message_types_by_name[
    "OriginalDetectIntentRequest"
] = _ORIGINALDETECTINTENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WebhookRequest = _reflection.GeneratedProtocolMessageType(
    "WebhookRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _WEBHOOKREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.webhook_pb2",
        "__doc__": """The request message for a webhook call.
  
  Attributes:
      session:
          The unique identifier of detectIntent request session. Can be
          used to identify end-user inside webhook implementation.
          Format: ``projects/<Project ID>/agent/sessions/<Session ID>``,
          or ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``.
      response_id:
          The unique identifier of the response. Contains the same value
          as ``[Streaming]DetectIntentResponse.response_id``.
      query_result:
          The result of the conversational query or event processing.
          Contains the same value as
          ``[Streaming]DetectIntentResponse.query_result``.
      original_detect_intent_request:
          Optional. The contents of the original request that was passed
          to ``[Streaming]DetectIntent`` call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.WebhookRequest)
    },
)
_sym_db.RegisterMessage(WebhookRequest)

WebhookResponse = _reflection.GeneratedProtocolMessageType(
    "WebhookResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _WEBHOOKRESPONSE,
        "__module__": "google.cloud.dialogflow_v2.proto.webhook_pb2",
        "__doc__": """The response message for a webhook call.  This response is validated
  by the Dialogflow server. If validation fails, an error will be
  returned in the [QueryResult.diagnostic_info][google.cloud.dialogflow.
  v2.QueryResult.diagnostic_info] field. Setting JSON fields to an empty
  value with the wrong type is a common error. To avoid this error:  -
  Use ``""`` for empty strings -  Use ``{}`` or ``null`` for empty
  objects -  Use ``[]`` or ``null`` for empty arrays  For more
  information, see the `Protocol Buffers Language Guide
  <https://developers.google.com/protocol-buffers/docs/proto3#json>`__.
  
  Attributes:
      fulfillment_text:
          Optional. The text response message intended for the end-user.
          It is recommended to use ``fulfillment_messages.text.text[0]``
          instead. When provided, Dialogflow uses this field to populate
          [QueryResult.fulfillment_text][google.cloud.dialogflow.v2.Quer
          yResult.fulfillment_text] sent to the integration or API
          caller.
      fulfillment_messages:
          Optional. The rich response messages intended for the end-
          user. When provided, Dialogflow uses this field to populate [Q
          ueryResult.fulfillment_messages][google.cloud.dialogflow.v2.Qu
          eryResult.fulfillment_messages] sent to the integration or API
          caller.
      source:
          Optional. A custom field used to identify the webhook source.
          Arbitrary strings are supported. When provided, Dialogflow
          uses this field to populate [QueryResult.webhook_source][googl
          e.cloud.dialogflow.v2.QueryResult.webhook_source] sent to the
          integration or API caller.
      payload:
          Optional. This field can be used to pass custom data from your
          webhook to the integration or API caller. Arbitrary JSON
          objects are supported. When provided, Dialogflow uses this
          field to populate [QueryResult.webhook_payload][google.cloud.d
          ialogflow.v2.QueryResult.webhook_payload] sent to the
          integration or API caller. This field is also used by the
          `Google Assistant integration
          <https://cloud.google.com/dialogflow/docs/integrations/aog>`__
          for rich response messages. See the format definition at
          `Google Assistant Dialogflow webhook format <https://developer
          s.google.com/assistant/actions/build/json/dialogflow-webhook-
          json>`__
      output_contexts:
          Optional. The collection of output contexts that will
          overwrite currently active contexts for the session and reset
          their lifespans. When provided, Dialogflow uses this field to
          populate [QueryResult.output_contexts][google.cloud.dialogflow
          .v2.QueryResult.output_contexts] sent to the integration or
          API caller.
      followup_event_input:
          Optional. Invokes the supplied events. When this field is set,
          Dialogflow ignores the ``fulfillment_text``,
          ``fulfillment_messages``, and ``payload`` fields.
      session_entity_types:
          Optional. Additional session entity types to replace or extend
          developer entity types with. The entity synonyms apply to all
          languages and persist for the session. Setting this data from
          a webhook overwrites the session entity types that have been
          set using ``detectIntent``, ``streamingDetectIntent`` or [Sess
          ionEntityType][google.cloud.dialogflow.v2.SessionEntityType]
          management methods.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.WebhookResponse)
    },
)
_sym_db.RegisterMessage(WebhookResponse)

OriginalDetectIntentRequest = _reflection.GeneratedProtocolMessageType(
    "OriginalDetectIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ORIGINALDETECTINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.webhook_pb2",
        "__doc__": """Represents the contents of the original request that was passed to the
  ``[Streaming]DetectIntent`` call.
  
  Attributes:
      source:
          The source of this request, e.g., ``google``, ``facebook``,
          ``slack``. It is set by Dialogflow-owned servers.
      version:
          Optional. The version of the protocol used for this request.
          This field is AoG-specific.
      payload:
          Optional. This field is set to the value of the
          ``QueryParameters.payload`` field passed in the request. Some
          integrations that query a Dialogflow agent may provide
          additional information in the payload.  In particular, for the
          Dialogflow Phone Gateway integration, this field has the form:
          .. raw:: html     <pre>{     "telephony": {       "caller_id":
          "+18558363987"     }    }</pre>  Note: The caller ID field
          (``caller_id``) will be redacted for Standard Edition agents
          and populated with the caller ID in `E.164 format
          <https://en.wikipedia.org/wiki/E.164>`__ for Enterprise
          Edition agents.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.OriginalDetectIntentRequest)
    },
)
_sym_db.RegisterMessage(OriginalDetectIntentRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
